@@ -14,13 +14,13 @@ from py_mini_racer import py_mini_racer
 import pandas as pd
 import requests
 
-from akshare.futures.cons import (
+from PPshare.futures.cons import (
     zh_subscribe_exchange_symbol_url,
     zh_match_main_contract_url,
     zh_match_main_contract_payload,
 )
-from akshare.futures.futures_contract_detail import futures_contract_detail
-from akshare.utils import demjson
+from PPshare.futures.futures_contract_detail import futures_contract_detail
+from PPshare.utils import demjson
 
 
 @lru_cache()
