@@ -13,7 +13,7 @@ import requests
 from bs4 import BeautifulSoup
 
 from PPshare.index.cons import short_headers
-from PPshare.utils.ak_session import session
+from PPshare.utils.pp_session import session
 
 
 def _get_global_index_area_name_code() -> dict:
