@@ -13,8 +13,8 @@ from bs4 import BeautifulSoup
 from py_mini_racer import py_mini_racer
 from tqdm import tqdm
 
-from akshare.datasets import get_ths_js
-from akshare.utils import demjson
+from PPshare.datasets import get_ths_js
+from PPshare.utils import demjson
 
 
 def _get_file_content_ths(file: str = "ths.js") -> str:
