@@ -8,7 +8,7 @@ https://legulegu.com/stockdata/ashares-congestion
 import pandas as pd
 import requests
 
-from akshare.stock_feature.stock_a_indicator import get_token_lg
+from PPshare.stock_feature.stock_a_indicator import get_token_lg
 
 
 def stock_a_congestion_lg() -> pd.DataFrame:
